searchNodes=[{"doc":"Compiler that checks for calls to code that is marked as private, typically via @moduledoc false and @doc false. This module is responsible for running the compiler and formatting warnings","ref":"Mix.Tasks.Compile.PrivCheck.html","title":"Mix.Tasks.Compile.PrivCheck","type":"task"},{"doc":"","ref":"Mix.Tasks.Compile.PrivCheck.html#print_diagnostics/1","title":"Mix.Tasks.Compile.PrivCheck.print_diagnostics/1","type":"function"},{"doc":"Documentation for PrivCheck.","ref":"PrivCheck.html","title":"PrivCheck","type":"module"},{"doc":"See PrivCheck.DocChecker.public_fun?/1.","ref":"PrivCheck.html#public_fun?/1","title":"PrivCheck.public_fun?/1","type":"function"},{"doc":"","ref":"PrivCheck.Config.html","title":"PrivCheck.Config","type":"module"},{"doc":"","ref":"PrivCheck.Config.html#from_file_system/0","title":"PrivCheck.Config.from_file_system/0","type":"function"},{"doc":"","ref":"PrivCheck.Config.html#ignore_calls_from_file/2","title":"PrivCheck.Config.ignore_calls_from_file/2","type":"function"},{"doc":"","ref":"PrivCheck.Config.html#ignore_references_to_module/2","title":"PrivCheck.Config.ignore_references_to_module/2","type":"function"},{"doc":"Find docs of module, caching results for performance Depends heavily on the documentation layout described and implemented in EEP 48: http://erlang.org/eeps/eep-0048.html","ref":"PrivCheck.DocChecker.html","title":"PrivCheck.DocChecker","type":"module"},{"doc":"","ref":"PrivCheck.DocChecker.html#mfa_visibility/1","title":"PrivCheck.DocChecker.mfa_visibility/1","type":"function"},{"doc":"Check the visiblity type of the given module","ref":"PrivCheck.DocChecker.html#mod_visibility/1","title":"PrivCheck.DocChecker.mod_visibility/1","type":"function"},{"doc":"Check if the given module is considered public","ref":"PrivCheck.DocChecker.html#public?/1","title":"PrivCheck.DocChecker.public?/1","type":"function"},{"doc":"","ref":"PrivCheck.DocChecker.html#public_fun?/1","title":"PrivCheck.DocChecker.public_fun?/1","type":"function"},{"doc":"","ref":"PrivCheck.DocChecker.html#t:visibility/0","title":"PrivCheck.DocChecker.visibility/0","type":"type"},{"doc":"Recorded traces","ref":"PrivCheck.Tracer.State.html","title":"PrivCheck.Tracer.State","type":"module"},{"doc":"","ref":"PrivCheck.Tracer.State.html#t:t/0","title":"PrivCheck.Tracer.State.t/0","type":"type"},{"doc":"","ref":"PrivCheck.TracesManifest.Traces.html","title":"PrivCheck.TracesManifest.Traces","type":"module"},{"doc":"","ref":"Short.html","title":"Short","type":"module"},{"doc":"","ref":"Short.html#abc/0","title":"Short.abc/0","type":"function"},{"doc":"","ref":"Short.html#hi/0","title":"Short.hi/0","type":"function"},{"doc":"","ref":"Short.html#hi2/0","title":"Short.hi2/0","type":"function"},{"doc":"","ref":"Short.Abc.html","title":"Short.Abc","type":"module"},{"doc":"PrivCheck Elixir libraries can define a private API by defining a module that is documented as @moduledoc false, or a function that is defined as @doc false, that module or function should not be called or referenced. PrivCheck is a library to generate warnings when private API&#39;s are called.","ref":"readme.html","title":"PrivCheck","type":"extras"},{"doc":"In Elixir it is quite easy to use private API&#39;s without realizing, especially if the developer is just copying code from a blog post since there are no warnings or errors emitted when using hidden modules. Part of Elixir&#39;s philosophy is to help developers fall into the pit of success (e.g. make it easy to do the right thing). So we should make it easy for a developer to avoid using the private API&#39;s. This library is my attempt to make this guideline easy to follow. The usage of private API&#39;s has caused downstream bugs, and resulted in a PSA due to inadvertant breakage in Elixir v1.7 Building the concept of Private Modules into the language has been proposed and accepted, but it has not yet been implemented.","ref":"readme.html#raison-detre","title":"PrivCheck - Raison D&#39;etre","type":"extras"},{"doc":"PrivCheck can be installed by adding priv_check to your list of dependencies in mix.exs: def deps do [ {:priv_check, &quot;~&gt; 0.2.1&quot;, only: [:dev, :test], runtime: false}, ] end Next, in your project&#39;s mix.exs file in your project function add :priv_check to the list of :compilers (adding it if it doesn&#39;t already exist). def project do [ ... compilers: [:priv_check] ++ Mix.compilers(), # If you&#39;re using Phoenix it will probably look a little more like this instead: compilers: [:priv_check, :phoenix, :gettext] ++ Mix.compilers(), ... ] end Then run mix clean and then mix compile","ref":"readme.html#installation","title":"PrivCheck - Installation","type":"extras"},{"doc":"A configuration file can be provided that allows you to configure the behavior of PrivCheck. In the root of your repository (same directory that has the mix.exs) add a .priv_check.exs file. Here are some sample contents: %{ # Relative path to files to skip checks for ignored_files: [&quot;lib/ignored.ex&quot;], # List of modules that are private, but warnings should be ignored ignore_references_to_modules: [] }","ref":"readme.html#configuration","title":"PrivCheck - Configuration","type":"extras"},{"doc":"@moduledoc false hides the module from documentation (as implemented in ex_doc) which is an indication that the module should not be used by consumers of the library.","ref":"readme.html#nomenclature-private-apis-vs-hidden-modules","title":"PrivCheck - Nomenclature: Private APIs vs Hidden modules","type":"extras"},{"doc":"After following the installation instructions, when you compile any code that accesses a private module or function will generate a warning. Here is a sample warning: warning: ExampleDep.Private.add/2 is not a public function and should not be called from other applications. Called from: PrivCheckExample. lib/priv_check_example.ex:21 Because PrivCheck is a mix compiler, it integrates seamlessly with editors which can work with mix compilers. For example, in VSCode with ElixirLS: And here is how it looks in VSCode&#39;s problems list:","ref":"readme.html#usage","title":"PrivCheck - Usage","type":"extras"},{"doc":"PrivCheck uses the compiler tracing feature that was released in Elixir v1.10. When elixir compiles the applications code it keeps a log of all referenced modules and function calls. PrivCheck looks at those modules and functions, and inspects their documentation to ascertain if they are hidden modules or functions, if they are it emits a warning for each violation.","ref":"readme.html#how-it-works","title":"PrivCheck - How it Works","type":"extras"},{"doc":"It is often expected that macro generated code will call hidden functions of its containing library (for performance reasons). One example of this is Logger.info/2 (v1.9.4) in the standard library will call Logger.__should_log__/2 which is @doc false. Since the compiler tracing runs after macros generate code, calling a macro like Logger.info/2 would result in a warning since the generated code calls a hidden function. In order to not raise false positives on such code, PrivCheck ignores any lines that call a remote macro.","ref":"readme.html#limitations","title":"PrivCheck - Limitations","type":"extras"},{"doc":"Returns duplicate-looking warnings #4","ref":"readme.html#known-issues","title":"PrivCheck - Known Issues","type":"extras"},{"doc":"Boundary: manage and restrain cross-module dependencies: https://github.com/sasa1977/boundary/ Was an inspiration for much of this library and can be used alongside Dialyzer @opaque types: a way to define that a specific struct or datatype should not be used outside of the module that it was defined in. https://hexdocs.pm/elixir/typespecs.html#user-defined-types https://hexdocs.pm/elixir/Kernel.html#defstruct/1-types Built-in private modules proposal: https://elixirforum.com/t/proposal-private-modules-general-discussion/19374/1 Jose Valim&#39;s experiment in adding defmodulep: https://github.com/josevalim/defmodulep","ref":"readme.html#related-concepts-and-libraries","title":"PrivCheck - Related Concepts and Libraries","type":"extras"}]